@@ -36,39 +36,46 @@ class Pixels:
 
     Attributes
     ----------
-    pixels: (M, N) np.ndarray[ndim=2, dtype=float64]
+    pixels : (M, N) np.ndarray[ndim=2, dtype=float64]
         The 2D numpy array containing the pixel values. This class assumes a
         uniform grid of pixels - that is, the pixel size in each dimension is
         constant, but can vary from one dimension to another.
 
-    xlim: (2,) np.ndarray[ndim=1, dtype=float64]
+    xlim : (2,) np.ndarray[ndim=1, dtype=float64]
         The lower and upper boundaries of the pixellised volume in the
         x-dimension, formatted as [x_min, x_max].
 
-    ylim: (2,) np.ndarray[ndim=1, dtype=float64]
+    ylim : (2,) np.ndarray[ndim=1, dtype=float64]
         The lower and upper boundaries of the pixellised volume in the
         y-dimension, formatted as [y_min, y_max].
 
-    pixel_size: (2,) np.ndarray[ndim=1, dtype=float64]
+    pixel_size : (2,) np.ndarray[ndim=1, dtype=float64]
         The lengths of a pixel in the x- and y-dimensions, respectively.
 
-    pixel_grids: list[(M+1,) np.ndarray, (N+1,) np.ndarray]
+    pixel_grids : list[(M+1,) np.ndarray, (N+1,) np.ndarray]
         A list containing the pixel gridlines in the x- and y-dimensions.
         Each dimension's gridlines are stored as a numpy of the pixel
         delimitations, such that it has length (M + 1), where M is the number
         of pixels in a given dimension.
 
-    lower: (2,) np.ndarray[ndim=1, dtype=float64]
+    lower : (2,) np.ndarray[ndim=1, dtype=float64]
         The lower left corner of the pixel rectangle; corresponds to
         [xlim[0], ylim[0]].
 
-    upper: (2,) np.ndarray[ndim=1, dtype=float64]
+    upper : (2,) np.ndarray[ndim=1, dtype=float64]
         The upper right corner of the pixel rectangle; corresponds to
         [xlim[1], ylim[1]].
 
-    attrs: dict[Any, Any]
+    attrs : dict[Any, Any]
         A dictionary storing any other user-defined information.
 
+    See Also
+    --------
+    konigcell.Voxels : A class managing a physical 3D voxel space.
+    konigcell.dynamic2d : Rasterize moving particles' trajectories.
+    konigcell.static2d : Rasterize static particles' positions.
+    konigcell.dynamic_prob2d : 2D probability distribution of a quantity.
+
     Notes
     -----
     The class saves `pixels` as a **contiguous** numpy array for efficient
@@ -77,14 +84,124 @@ class Pixels:
 
     Examples
     --------
-    TODO
+    Create a zeroed 4x4 Pixels grid:
 
-    See Also
-    --------
-    konigcell.Voxels : a class managing a physical 3D voxel space.
-    konigcell.dynamic2d : rasterize moving particles' trajectories.
-    konigcell.static2d : rasterize static particles' positions.
-    konigcell.dynamic_prob2d : 2D probability distribution of a quantity.
+    >>> import konigcell as kc
+    >>> pixels = kc.Pixels.zeros((4, 4), xlim = [0, 10], ylim = [0, 5])
+    >>> pixels
+    Pixels
+    ------
+    xlim = [ 0. 10.]
+    ylim = [0. 5.]
+    pixels =
+      (shape: (4, 4))
+      [[0. 0. 0. 0.]
+       [0. 0. 0. 0.]
+       [0. 0. 0. 0.]
+       [0. 0. 0. 0.]]
+    attrs = {}
+
+    Or create a Pixels instance from another array (e.g. an image or matrix):
+
+    >>> import numpy as np
+    >>> matrix = np.ones((3, 3))
+    >>> pixels = kc.Pixels(matrix, xlim = [0, 10], ylim = [-5, 5])
+    >>> pixels
+    Pixels
+    ------
+    xlim = [ 0. 10.]
+    ylim = [-5.  5.]
+    pixels =
+      (shape: (3, 3))
+      [[1. 1. 1.]
+       [1. 1. 1.]
+       [1. 1. 1.]]
+    attrs = {}
+
+    Access pixels' properties directly:
+
+    >>> pixels.xlim             # ndarray[xmin, xmax]
+    >>> pixels.ylim             # ndarray[ymin, ymax]
+    >>> pixels.pixel_size       # ndarray[xsize, ysize]
+    >>> pixels.pixels.shape     # pixels resolution - tuple[nx, ny]
+
+    You can save extra attributes about the pixels instance in the `attrs`
+    dictionary:
+
+    >>> pixels.attrs["dpi"] = 300
+    >>> pixels
+    Pixels
+    ------
+    xlim = [ 0. 10.]
+    ylim = [-5.  5.]
+    pixels =
+      (shape: (3, 3))
+      [[1. 1. 1.]
+       [1. 1. 1.]
+       [1. 1. 1.]]
+    attrs = {
+      'dpi': 300
+    }
+
+    The lower left and upper right corners of the pixel grid, in physical
+    coordinates (the ones given by xlim and ylim):
+
+    >>> pixels.lower
+    array([ 0., -5.])
+
+    >>> pixels.upper
+    array([10.,  5.])
+
+    You can access the underlying NumPy array directly:
+
+    >>> pixels.pixels
+    array([[1., 1., 1.],
+           [1., 1., 1.],
+           [1., 1., 1.]])
+
+    Indexing is forwarded to the NumPy array:
+
+    >>> pixels[:, :]
+    array([[1., 1., 1.],
+           [1., 1., 1.],
+           [1., 1., 1.]])
+
+    Transform physical units into pixel indices:
+
+    >>> pixels.from_physical([5, 0])                    # pixel centres
+    array([1., 1.])
+
+    >>> pixels.from_physical([5, 0], corner = True)     # lower left corners
+    array([1.5, 1.5])
+
+    Transform pixel indices into physical units:
+
+    >>> pixels.to_physical([0, 0])                      # pixels centres
+    array([ 1.66666667, -3.33333333])
+
+    >>> pixels.to_physical([0, 0], corner = True)       # lower left corners
+    array([ 0., -5.])
+
+    Save Pixels instance to disk, as a binary archive:
+
+    >>> pixels.save("pixels.pickle")
+    >>> pixels = kc.load("pixels.pickle")
+
+    Create deep copy of a Pixels instance:
+
+    >>> Pixels.copy()
+
+    Matplotlib plotting (optional, if Matplotlib is installed):
+
+    >>> fig, ax = pixels.plot()
+    >>> fig.show()
+
+    Plotly trace (optional, if Plotly is installed):
+
+    >>> import plotly.graph_objs as go
+    >>> fig = go.Figure()
+    >>> fig.add_trace(pixels.heatmap_trace())
+    >>> fig.show()
     '''
     __slots__ = ("_pixels", "_xlim", "_ylim", "_attrs", "_pixel_size",
                  "_pixel_grids", "_lower", "_upper")
@@ -94,18 +211,18 @@ class Pixels:
 
         Parameters
         ----------
-        pixels_array: 3D numpy.ndarray
+        pixels_array : 3D numpy.ndarray
             A 3D numpy array, corresponding to a pre-defined pixel space.
 
-        xlim: (2,) numpy.ndarray
+        xlim : (2,) numpy.ndarray
             The lower and upper boundaries of the pixellised volume in the
             x-dimension, formatted as [x_min, x_max].
 
-        ylim: (2,) numpy.ndarray
+        ylim : (2,) numpy.ndarray
             The lower and upper boundaries of the pixellised volume in the
             y-dimension, formatted as [y_min, y_max].
 
-        kwargs: extra keyword arguments
+        **kwargs : extra keyword arguments
             Extra user-defined attributes to be saved in `.attrs`.
 
         Raises
@@ -118,7 +235,6 @@ class Pixels:
         -----
         No copies are made if `pixels_array`, `xlim` and `ylim` are contiguous
         NumPy arrays with dtype=float64.
-
         '''
 
         # Type-checking inputs
@@ -159,7 +275,7 @@ class Pixels:
         self._pixels = pixels_array
         self._xlim = xlim
         self._ylim = ylim
-        self._attrs = kwargs
+        self._attrs = dict(kwargs)
 
 
     @property
@@ -254,7 +370,6 @@ class Pixels:
         >>> pixels.save("pixels.pickle")
 
         >>> pixels_reloaded = kc.Pixels.load("pixels.pickle")
-
         '''
         with open(filepath, "wb") as f:
             pickle.dump(self, f)
@@ -289,7 +404,6 @@ class Pixels:
         >>> pixels.save("pixels.pickle")
 
         >>> pixels_reloaded = kc.Pixels.load("pixels.pickle")
-
         '''
         with open(filepath, "rb") as f:
             obj = pickle.load(f)
@@ -365,7 +479,6 @@ class Pixels:
         >>> pixels.from_physical([[0, 15], [5, 20]])
         array([[2. , 2. ],
                [4.5, 4.5]])
-
         '''
 
         offset = 0. if corner else self.pixel_size / 2
@@ -414,7 +527,6 @@ class Pixels:
         >>> pixels.to_physical([[0, 0], [4, 3]])
         array([[-4., 11.],
                [ 4., 17.]])
-
         '''
 
         offset = 0. if corner else self.pixel_size / 2
@@ -455,7 +567,6 @@ class Pixels:
         >>> fig = go.Figure()
         >>> fig.add_trace(pixels.heatmap_trace())
         >>> fig.show()
-
         '''
 
         # Compute the pixel centres
@@ -494,7 +605,8 @@ class Pixels:
 
         Returns
         -------
-        fig, ax : matplotlib figure and axes objects
+        fig, ax
+            Matplotlib figure and axes objects.
 
         Examples
         --------
@@ -507,7 +619,6 @@ class Pixels:
 
         >>> fig, ax = pixels.plot()
         >>> fig.show()
-
         '''
 
         # If you see this error, it means you don't have Matplotlib; install it
@@ -522,11 +633,11 @@ class Pixels:
         ax.imshow(np.rot90(self.pixels))
 
         # Compute the pixel centres and set them in the Matplotlib image
-        x = self.pixel_grids[0]
-        x = (x[1:] + x[:-1]) / 2
+        # x = self.pixel_grids[0]
+        # x = (x[1:] + x[:-1]) / 2
 
-        y = self.pixel_grids[1]
-        y = (y[1:] + y[:-1]) / 2
+        # y = self.pixel_grids[1]
+        # y = (y[1:] + y[:-1]) / 2
 
         # Matplotlib shows numbers in a long format ("102.000032411"), so round
         # them to two decimals before plotting
